/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { Configuration as n } from "./base/ConfigurationComponent.mjs";
import { noop as i, getDefaultSlots as r } from "@progress/kendo-vue-common";
import { removeUndefinedProps as d } from "../utils/main.mjs";
import { defineComponent as u, h as o } from "vue";
const c = /* @__PURE__ */ u({
  name: "KendoChartSeriesItem",
  props: {
    autoFit: Boolean,
    aggregate: {
      type: [String, Function, Object],
      default: function() {
      }
    },
    axis: String,
    border: {
      type: Object,
      default: function() {
      }
    },
    categoryAxis: String,
    categoryField: String,
    closeField: String,
    color: {
      type: [String, Function],
      default: function() {
      }
    },
    colorField: String,
    connectors: {
      type: Object,
      default: function() {
      }
    },
    currentField: String,
    dashType: {
      type: String,
      default: function() {
      },
      validator: function(e) {
        return ["dash", "dashDot", "dot", "longDash", "longDashDot", "longDashDotDot", "solid"].includes(e);
      }
    },
    dataItems: {
      type: Array,
      default: function() {
      }
    },
    downColor: String,
    downColorField: String,
    dynamicHeight: {
      type: Boolean,
      default: void 0
    },
    dynamicSlope: {
      type: Boolean,
      default: void 0
    },
    errorHighField: String,
    errorLowField: String,
    explodeField: String,
    field: String,
    for: String,
    fromField: String,
    gap: Number,
    highField: String,
    holeSize: Number,
    line: {
      type: Object,
      default: function() {
      }
    },
    lowField: String,
    lowerField: String,
    margin: {
      type: [Object, Number],
      default: function() {
      }
    },
    maxSize: Number,
    meanField: String,
    medianField: String,
    minSize: Number,
    missingValues: {
      type: String,
      default: function() {
      },
      validator: function(e) {
        return ["gap", "interpolate", "zero"].includes(e);
      }
    },
    name: String,
    neckRatio: Number,
    negativeColor: String,
    negativeValues: {
      type: Object,
      default: function() {
      }
    },
    noteTextField: String,
    opacity: Number,
    openField: String,
    outliersField: String,
    overlay: {
      type: Object,
      default: function() {
      }
    },
    padding: Number,
    q1Field: String,
    q3Field: String,
    segmentSpacing: Number,
    size: Number,
    sizeField: String,
    spacing: Number,
    stack: {
      type: [Boolean, String, Object],
      default: function() {
      }
    },
    startAngle: Number,
    lineStyle: {
      type: String,
      default: function() {
      },
      validator: function(e) {
        return ["normal", "step", "smooth"].includes(e);
      }
    },
    summaryField: String,
    target: {
      type: Object,
      default: function() {
      }
    },
    toField: String,
    type: {
      type: String,
      default: function() {
      }
    },
    upperField: String,
    visible: {
      type: Boolean,
      default: void 0
    },
    visibleInLegend: {
      type: Boolean,
      default: void 0
    },
    visibleInLegendField: String,
    visual: {
      type: Function,
      default: void 0
    },
    width: Number,
    xAxis: String,
    xErrorHighField: String,
    xErrorLowField: String,
    xField: String,
    yAxis: String,
    yErrorHighField: String,
    yErrorLowField: String,
    yField: String,
    zIndex: Number,
    errorBars: {
      type: Object,
      default: function() {
      }
    },
    extremes: {
      type: Object,
      default: function() {
      }
    },
    highlight: {
      type: Object,
      default: function() {
      }
    },
    /**
     * The configuration of the Chart series label. The Chart displays the series labels when the [`series.labels.visible`]({% slug api_charts_chartserieslabelsprops %}#toc-visible) option is set to `true`.
     */
    labels: {
      type: Object,
      default: function() {
      }
    },
    markers: {
      type: Object,
      default: function() {
      }
    },
    legendItem: {
      type: Object,
      default: function() {
      }
    },
    notes: {
      type: Object,
      default: function() {
      }
    },
    outliers: {
      type: Object,
      default: function() {
      }
    },
    tooltip: {
      type: Object,
      default: function() {
      }
    },
    pattern: {
      type: [Object, Function],
      default: function() {
      }
    },
    patternField: String
  },
  inject: {
    chartRefresh: {
      default: i
    }
  },
  watch: {
    dataItems: {
      handler() {
        this.chartRefresh();
      },
      deep: !0
    }
  },
  render() {
    const e = r(this), t = d(this.$props);
    return o(n, {
      config: t
    }, function() {
      return e;
    });
  }
});
export {
  c as ChartSeriesItem
};
